import { NDKFilter } from '@nostr-dev-kit/ndk'
import { nip19 } from 'nostr-tools'
import { useState } from 'react'
import { useLocation, useParams } from 'react-router-dom'
import { toast } from 'react-toastify'
import { LoadingSpinner } from '../components/LoadingSpinner'
import { ModForm } from '../components/ModForm'
import { ProfileSection } from '../components/ProfileSection'
import { useAppSelector, useDidMount, useNDKContext } from '../hooks'
import '../styles/innerPage.css'
import '../styles/styles.css'
import '../styles/write.css'
import { ModDetails } from '../types'
import { extractModData, log, LogType } from '../utils'

export const SubmitModPage = () => {
  const location = useLocation()
  const { naddr } = useParams()
  const { fetchEvent } = useNDKContext()
  const [modData, setModData] = useState<ModDetails>()
  const [isFetching, setIsFetching] = useState(false)

  const userState = useAppSelector((state) => state.user)

  const title = location.pathname.startsWith('/edit-mod')
    ? 'Edit Mod'
    : 'Submit a mod'

  useDidMount(async () => {
    if (naddr) {
      const decoded = nip19.decode<'naddr'>(naddr as `naddr1${string}`)
      const { identifier, kind, pubkey } = decoded.data

      const filter: NDKFilter = {
        '#a': [identifier],
        authors: [pubkey],
        kinds: [kind]
      }

      setIsFetching(true)

      fetchEvent(filter)
        .then((event) => {
          if (event) {
            const extracted = extractModData(event)
            setModData(extracted)
          }
        })
        .catch((err) => {
          log(
            true,
            LogType.Error,
            'An error occurred in fetching mod details from relays',
            err
          )
          toast.error('An error occurred in fetching mod details from relays')
        })
        .finally(() => {
          setIsFetching(false)
        })
    }
  })
  return (
    <div className='InnerBodyMain'>
      <div className='ContainerMain'>
        <div className='IBMSecMainGroup IBMSecMainGroupAlt'>
          <div className='IBMSMSplitMain'>
            <div className='IBMSMSplitMainBigSide'>
              <div className='IBMSMTitleMain'>
                <h2 className='IBMSMTitleMainHeading'>{title}</h2>
              </div>
              <div className='IBMSMSMBS_Write'>
                {isFetching ? (
                  <LoadingSpinner desc='Fetching mod details from relays' />
                ) : (
                  <ModForm existingModData={modData} />
                )}
              </div>
            </div>
            {userState.auth && userState.user?.pubkey && (
              <ProfileSection pubkey={userState.user.pubkey as string} />
            )}
          </div>
        </div>
      </div>
    </div>
  )
}
